@@ -22,9 +22,7 @@ class Command(BaseCommand):
         Queues the function given with the first argument with the
         parameters given with the rest of the argument list.
         """
-        verbosity = int(options.get('verbosity', 1))
-        timeout = options.get('timeout')
-        queue = get_queue(options.get('queue'))
-        job = queue.enqueue_call(args[0], args=args[1:], timeout=timeout)
-        if verbosity:
+        queue = get_queue(options['queue'])
+        job = queue.enqueue_call(args[0], args=args[1:], timeout=options['timeout'])
+        if options['verbosity']:
             print('Job %s created' % job.id)
